﻿using System;
using System.Collections.Generic;
using System.Text;
using System.Threading;

namespace bo
{
    public class ConsoleProgram
    {
        #region tools

        public string ExecutableName
        {
            get
            {
                string result = AssemblyHelper.ExecutableName;
                return result;
            }
        }

        public void WaitForEnter()
        {
            Console.Write("Press <Enter>");
            Console.ReadLine();
        }

        #endregion

        #region logic

        protected virtual void logic(string arg)
        {
        }

        protected virtual void logic(string[] args)
        {
            foreach (string arg in args)
            {
                logic(arg);
            }
        }

        #endregion

        #region main

        protected virtual void regularMain(string[] args)
        {
            try
            {
                logic(args);
            }
            catch (Exception ex)
            {
                log(ex);
                log(ex.StackTrace);
            }
        }

        protected virtual void debugMain(string[] args)
        {
            try
            {
                regularMain(args);
            }
            finally
            {
                WaitForEnter();
            }
        }

        #endregion

        #region log

        public static IFormatProvider FormatProvider
        {
            get
            {
                return Thread.CurrentThread.CurrentCulture;
            }
        }
        public static void log(string value)
        {
            Console.WriteLine(value);
        }

        public static void log(object value)
        {
            if (value != null)
            {
                IFormattable formattable1 = value as IFormattable;
                if (formattable1 != null)
                {
                    log(formattable1.ToString(null, FormatProvider));
                }
                else
                {
                    log(value.ToString());
                }
            }
        }

        public static void log(string format, object arg0)
        {
            log(string.Format(FormatProvider, format, new object[] { arg0 }));
        }

        public static void log(string format, object arg0, object arg1)
        {
            log(string.Format(FormatProvider, format, new object[] { arg0, arg1 }));
        }

        public static void log(string format, object arg0, object arg1, object arg2)
        {
            log(string.Format(FormatProvider, format, new object[] { arg0, arg1, arg2 }));
        }

        public static void log(string format, params object[] arg)
        {
            log(string.Format(FormatProvider, format, arg));
        }

        public static void log(object[] args)
        {
            foreach (object arg in args)
                log(arg);
        }

        public static void log(List<object> args)
        {
            foreach (object arg in args)
                log(arg);
        }

        protected static void log(List<string> args)
        {
            foreach (string arg in args)
                log(arg);
        }

        public static string ToString(TimeSpan timespan)
        {
            // TODO: take into account the current locale (is the '.' always a '.' ???)
            string result = timespan.ToString();
            while
                (
                (result.Length > 8) &&
                ((result[result.Length - 1] == '0') || (result[result.Length - 1] == '.'))
                )
            {
                result = result.Substring(0, result.Length - 2);
            }
            return result;
        }

        #endregion
    }
}
